@@ -129,6 +129,8 @@ check_command (char *command)
 
         g_shell_parse_argv (command, NULL, &argv, NULL);
         path = find_command (argv [0]);
+        g_strfreev (argv);
+
         if (path) {
                 g_free (path);
                 return TRUE;
@@ -631,7 +633,7 @@ spawn_on_widget (GtkWidget  *widget,
                 g_free (argv [0]);
                 argv [0] = path;
         }
-
+        
         env = g_ptr_array_new ();
 
         str = widget_get_id_string (widget);
@@ -647,7 +649,14 @@ spawn_on_widget (GtkWidget  *widget,
         g_ptr_array_add (env, g_strdup_printf ("PATH=%s", g_getenv ("PATH")));
 
         if (g_getenv ("XAUTHORITY"))
-                g_ptr_array_add (env, g_strdup_printf ("XAUTHORITY=%s", g_getenv ("XAUTHORITY")));
+                g_ptr_array_add (env, g_strdup_printf ("XAUTHORITY=%s",
+                                                       g_getenv ("XAUTHORITY")));
+        if (g_getenv ("LANG"))
+                g_ptr_array_add (env, g_strdup_printf ("LANG=%s",
+                                                       g_getenv ("LANG")));
+        if (g_getenv ("LANGUAGE"))
+                g_ptr_array_add (env, g_strdup_printf ("LANGUAGE=%s",
+                                                       g_getenv ("LANGUAGE")));
         g_ptr_array_add (env, NULL);
 
         result = gdk_spawn_on_screen_with_pipes (gtk_widget_get_screen (widget),
