@@ -21,6 +21,7 @@
  */
 
 #include "config.h"
+
 #include <time.h>
 #include <gdk/gdk.h>
 
@@ -31,6 +32,8 @@
 #include "gs-job.h"
 #include "gs-grab.h"
 
+#include "fade.h"
+
 static void gs_manager_class_init (GSManagerClass *klass);
 static void gs_manager_init       (GSManager      *manager);
 static void gs_manager_finalize   (GObject        *object);
@@ -52,6 +55,8 @@ struct GSManagerPrivate
         guint        user_switch_enabled : 1;
         guint        throttle_enabled : 1;
 
+        char        *logout_command;
+
         /* State */
         guint        blank_active : 1;
         guint        lock_active : 1;
@@ -81,6 +86,7 @@ enum {
         PROP_LOCK_TIMEOUT,
         PROP_CYCLE_TIMEOUT,
         PROP_LOGOUT_TIMEOUT,
+        PROP_LOGOUT_COMMAND,
         PROP_BLANK_ACTIVE,
         PROP_THROTTLE_ENABLED,
 };
@@ -257,6 +263,21 @@ gs_manager_set_logout_timeout (GSManager *manager,
         }
 }
 
+void
+gs_manager_set_logout_command (GSManager  *manager,
+                               const char *command)
+{
+        g_return_if_fail (GS_IS_MANAGER (manager));
+
+        g_free (manager->priv->logout_command);
+
+        if (command) {
+                manager->priv->logout_command = g_strdup (command);
+        } else {
+                manager->priv->logout_command = NULL;
+        }
+}
+
 static const char *
 select_theme (GSManager *manager)
 {
@@ -391,6 +412,9 @@ gs_manager_set_property (GObject            *object,
         case PROP_LOGOUT_TIMEOUT:
                 gs_manager_set_logout_timeout (self, g_value_get_long (value));
                 break;
+        case PROP_LOGOUT_COMMAND:
+                gs_manager_set_logout_command (self, g_value_get_string (value));
+                break;
         case PROP_CYCLE_TIMEOUT:
                 gs_manager_set_cycle_timeout (self, g_value_get_long (value));
                 break;
@@ -429,6 +453,9 @@ gs_manager_get_property (GObject            *object,
         case PROP_LOGOUT_TIMEOUT:
                 g_value_set_long (value, self->priv->logout_timeout);
                 break;
+        case PROP_LOGOUT_COMMAND:
+                g_value_set_string (value, self->priv->logout_command);
+                break;
         case PROP_CYCLE_TIMEOUT:
                 g_value_set_long (value, self->priv->cycle_timeout);
                 break;
@@ -519,6 +546,13 @@ gs_manager_class_init (GSManagerClass *klass)
                                                             G_MAXLONG,
                                                             0,
                                                             G_PARAM_READWRITE));
+        g_object_class_install_property (object_class,
+                                         PROP_LOGOUT_TIMEOUT,
+                                         g_param_spec_string ("logout-command",
+                                                              NULL,
+                                                              NULL,
+                                                              NULL,
+                                                              G_PARAM_READWRITE));
         g_object_class_install_property (object_class,
                                          PROP_CYCLE_TIMEOUT,
                                          g_param_spec_long ("cycle-timeout",
@@ -573,6 +607,8 @@ gs_manager_finalize (GObject *object)
 
         g_return_if_fail (manager->priv != NULL);
 
+        g_free (manager->priv->logout_command);
+
         remove_blank_timers (manager);
 
         gs_grab_release_keyboard_and_mouse ();
@@ -769,9 +805,10 @@ gs_manager_create_window (GSManager *manager,
         for (i = 0; i < n_monitors; i++) {
                 window = gs_window_new (screen, i, manager->priv->lock_active);
 
-                gs_window_set_logout_enabled (window, manager->priv->logout_enabled);
                 gs_window_set_user_switch_enabled (window, manager->priv->user_switch_enabled);
+                gs_window_set_logout_enabled (window, manager->priv->logout_enabled);
                 gs_window_set_logout_timeout (window, manager->priv->logout_timeout);
+                gs_window_set_logout_command (window, manager->priv->logout_command);
 
                 g_signal_connect_object (window, "unblanked",
                                          G_CALLBACK (window_unblanked_cb), manager, 0);
@@ -829,7 +866,6 @@ gs_manager_blank (GSManager *manager)
 {
         GdkDisplay *display;
         GdkScreen  *screen;
-        GSList     *l;
         GdkWindow  *root;
 
         g_return_val_if_fail (manager != NULL, FALSE);
@@ -850,9 +886,8 @@ gs_manager_blank (GSManager *manager)
         if (! manager->priv->windows)
                 gs_manager_create (GS_MANAGER (manager));
 
-        for (l = manager->priv->windows; l; l = l->next) {
-                gs_window_show (GS_WINDOW (l->data));
-        }
+        /* fade to black and show windows */
+        fade_screens_and_show (3, 20, TRUE, manager->priv->windows);
 
         return TRUE;
 }
@@ -903,3 +938,32 @@ gs_manager_is_blanked (GSManager *manager)
 
         return manager->priv->blank_active;
 }
+
+void
+gs_manager_request_unlock (GSManager *manager)
+{
+        GSList     *l;
+        GdkDisplay *display;
+        GdkScreen  *screen;
+        int         screen_num;
+
+        g_return_if_fail (manager != NULL);
+        g_return_if_fail (GS_IS_MANAGER (manager));
+
+        if (! manager->priv->blank_active)
+                return;
+
+        /* Find the screen that contains the pointer */
+        display = gdk_display_get_default ();
+        gdk_display_get_pointer (display, &screen, NULL, NULL, NULL);
+        screen_num = gdk_screen_get_number (screen);
+
+        /* Find the gs-window that is on that screen */
+        for (l = manager->priv->windows; l; l = l->next) {
+                int num = gdk_screen_get_number (GTK_WINDOW (l->data)->screen);
+                if (num == screen_num) {
+                        gs_window_request_unlock (GS_WINDOW (l->data));
+                        break;
+                }
+        }
+}
