@@ -45,7 +45,7 @@ typedef struct
         GObjectClass      parent_class;
 
         gboolean          (* idle)        (GSWatcher *watcher,
-                                           gint       flags);
+                                           int        reserved);
 } GSWatcherClass;
 
 GType       gs_watcher_get_type (void);
@@ -56,10 +56,5 @@ void        gs_watcher_set_active       (GSWatcher *watcher,
                                          gboolean   active);
 void        gs_watcher_set_timeout      (GSWatcher *watcher,
                                          guint      timeout);
-void        gs_watcher_set_dpms         (GSWatcher *watcher,
-                                         gboolean   enabled,
-                                         guint      standby,
-                                         guint      suspend,
-                                         guint      off);
 
 #endif /* __GS_WATCHER_H */
